﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace CustomActionsCS
{

    /// <summary>
    /// This class defines the UserControl that will display and allow editing of action-specific options. It is shared by all instances of the same action!
    /// </summary>
    internal partial class aCycleBytesUI : UserControl
    {

        public aCycleBytesUI()
        {
            InitializeComponent();
            this.nudValue.ValueChanged += nudValue_ValueChanged;
        }

        /// <summary>
        /// Holds a reference to the current action options object that is being displayed / edited by this control.
        /// </summary>
        aCycleBytesOptions opt;
        /// <summary>
        /// Helper variable that prevents modification of action options when the various UI controls are being set.
        /// </summary>

        bool _silent = true;
        /// <summary>
        /// This is a very important routine that is responsible for "binding" this user control to display and allow editing of a particular underlying action options object.
        /// </summary>
        /// <param name="aOptions">The actions options object that should be edited.</param>
        /// <remarks></remarks>
        internal void Prepare(ref aCycleBytesOptions aOptions)
        {
            opt = (aCycleBytesOptions)aOptions;
            //assign reference
            //customize UI according to options
            _silent = true;
            //prevent raising of events
            this.nudValue.Value = (decimal)opt.Value;
            //set the value of all the UI controls to the corresponding values from the action options
            _silent = false;
            //allow raising of events
        }

        /// <summary>
        /// Updates action options whenever NumericUpDown changed its value.
        /// </summary>
        private void nudValue_ValueChanged(object sender, EventArgs e)
        {
            if (_silent)
                return;
            opt.Value = (short)this.nudValue.Value;
            //set the options value
        }
    }

}