﻿''' <summary>
''' This class defines the UserControl that will display and allow editing of action-specific options. It is shared by all instances of the same action!
''' </summary>
Friend Class aCycleBytesUI

    ''' <summary>
    ''' Holds a reference to the current action options object that is being displayed / edited by this control.
    ''' </summary>
    Dim opt As aCycleBytesOptions
    ''' <summary>
    ''' Helper variable that prevents modification of action options when the various UI controls are being set.
    ''' </summary>
    Dim _silent As Boolean = True

    ''' <summary>
    ''' This is a very important routine that is responsible for "binding" this user control to display and allow editing of a particular underlying action options object.
    ''' </summary>
    ''' <param name="aOptions">The actions options object that should be edited.</param>
    ''' <remarks></remarks>
    Friend Sub Prepare(ByRef aOptions As aCycleBytesOptions)
        opt = CType(aOptions, aCycleBytesOptions) 'assign reference
        'customize UI according to options
        _silent = True 'prevent raising of events
        nudValue.Value = CDec(opt.Value) 'set the value of all the UI controls to the corresponding values from the action options
        _silent = False 'allow raising of events
    End Sub

    ''' <summary>
    ''' Updates action options whenever NumericUpDown changed its value.
    ''' </summary>
    Private Sub nudValue_ValueChanged(sender As Object, e As EventArgs) Handles nudValue.ValueChanged
        If _silent Then Exit Sub
        opt.Value = CShort(nudValue.Value) 'set the options value
    End Sub
End Class
